@@ -52,8 +52,8 @@ export class BaseView {
       this.selfView = new SelfView(this.element, this.server, this.responseEditorLoader, data, this);
       this.peerView = new PeerView(this.element, this.server, this.responseEditorLoader, data, this);
       this.staffView = new StaffView(this.element, this.server, this);
-      this.gradeView = new GradeView(this.element, this.server, this);
-      this.leaderboardView = new LeaderboardView(this.element, this.server, this);
+      this.gradeView = new GradeView(this.element, this.server, this.responseEditorLoader, data, this);
+      this.leaderboardView = new LeaderboardView(this.element, this.server, this.responseEditorLoader, data, this);
       this.messageView = new MessageView(this.element, this.server, this);
       // Staff-only area with information and tools for managing student submissions
       this.staffAreaView = new StaffAreaView(this.element, this.server, this.responseEditorLoader, data, this);
